@@ -28,44 +28,32 @@ class SelloutDict2(RootModel):
 
 
 class SelloutDict3(BaseModel):
-    model_config = {
-        "extra": "allow"
-    }
+    model_config = {"extra": "allow"}
 
 
-@app.post('/api/v1/sellouts',
-          tags=[Tag(name='Sellout', description='Loren.')],
-          responses={200: SelloutList}
-          )
+@app.post("/api/v1/sellouts", tags=[Tag(name="Sellout", description="Loren.")], responses={200: SelloutList})
 def post_sellout(body: SelloutList):
     print(body)
     return body.model_dump()
 
 
-@app.post('/api/v2/sellouts',
-          tags=[Tag(name='Sellout', description='Loren.')],
-          responses={200: SelloutDict}
-          )
+@app.post("/api/v2/sellouts", tags=[Tag(name="Sellout", description="Loren.")], responses={200: SelloutDict})
 def post_sellout2(body: SelloutDict):
     print(body)
     return body.model_dump()
 
 
-@app.post('/api/v3/sellouts',
-          tags=[Tag(name='Sellout', description='Loren.')]
-          )
+@app.post("/api/v3/sellouts", tags=[Tag(name="Sellout", description="Loren.")])
 def post_sellout3(body: SelloutDict2):
     print(body)
     return body.model_dump()
 
 
-@app.post('/api/v4/sellouts',
-          tags=[Tag(name='Sellout', description='Loren.')]
-          )
+@app.post("/api/v4/sellouts", tags=[Tag(name="Sellout", description="Loren.")])
 def post_sellout4(body: SelloutDict3):
     print(body)
     return body.model_dump()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     app.run(debug=True)
