@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/9/12 17:19
-from flask_openapi3 import OpenAPI
-from flask_openapi3 import RawModel
+from flask_openapi3 import OpenAPI, RawModel
 
 app = OpenAPI(__name__)
 
