@@ -3,7 +3,7 @@
 # @Time    : 2021/5/11 14:03
 from pydantic import BaseModel, Field
 
-from flask_openapi3 import OpenAPI, FileStorage
+from flask_openapi3 import FileStorage, OpenAPI
 
 app = OpenAPI(__name__)
 
@@ -19,15 +19,15 @@ class UploadFilesForm(BaseModel):
     int_list: list[int]
 
 
-@app.post('/upload/file')
+@app.post("/upload/file")
 def upload_file(form: UploadFileForm):
     print(form.file.filename)
     print(form.file_type)
-    form.file.save('test.jpg')
+    form.file.save("test.jpg")
     return {"code": 0, "message": "ok"}
 
 
-@app.post('/upload/files')
+@app.post("/upload/files")
 def upload_files(form: UploadFilesForm):
     print(form.files)
     print(form.str_list)
@@ -35,5 +35,5 @@ def upload_files(form: UploadFilesForm):
     return {"code": 0, "message": "ok"}
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     app.run(debug=True)
