@@ -2,39 +2,39 @@
 # @Author  : llc
 # @Time    : 2022/4/1 16:54
 import inspect
-from typing import Optional, Any, Callable
+from typing import Any, Callable
 
 from flask import Blueprint
 
-from .models import ExternalDocumentation
-from .models import Server
-from .models import Tag
+from .models import ExternalDocumentation, Server, Tag
 from .scaffold import APIScaffold
-from .types import ParametersTuple
-from .types import ResponseDict
-from .utils import HTTPMethod
-from .utils import convert_responses_key_to_string
-from .utils import get_operation
-from .utils import get_operation_id_for_path
-from .utils import get_responses
-from .utils import parse_and_store_tags
-from .utils import parse_method
-from .utils import parse_parameters
-from .utils import parse_rule
+from .types import ParametersTuple, ResponseDict
+from .utils import (
+    HTTPMethod,
+    convert_responses_key_to_string,
+    get_operation,
+    get_operation_id_for_path,
+    get_responses,
+    parse_and_store_tags,
+    parse_method,
+    parse_parameters,
+    parse_rule,
+)
 
 
 class APIBlueprint(APIScaffold, Blueprint):
     def __init__(
-            self,
-            name: str,
-            import_name: str,
-            *,
-            abp_tags: Optional[list[Tag]] = None,
-            abp_security: Optional[list[dict[str, list[str]]]] = None,
-            abp_responses: Optional[ResponseDict] = None,
-            doc_ui: bool = True,
-            operation_id_callback: Callable = get_operation_id_for_path,
-            **kwargs: Any
+        self,
+        name: str,
+        import_name: str,
+        *,
+        abp_tags: list[Tag] | None = None,
+        abp_security: list[dict[str, list[str]]] | None = None,
+        abp_responses: ResponseDict | None = None,
+        doc_ui: bool = True,
+        operation_id_callback: Callable = get_operation_id_for_path,
+        validate_response: bool | None = None,
+        **kwargs: Any,
     ) -> None:
         """
         Based on Flask Blueprint
@@ -50,6 +50,7 @@ class APIBlueprint(APIScaffold, Blueprint):
             operation_id_callback: Callback function for custom operation_id generation.
                                    Receives name (str), path (str) and method (str) parameters.
                                    Defaults to `get_operation_id_for_path` from utils
+            validate_response: Verify the response body.
             **kwargs: Flask Blueprint kwargs
         """
         super(APIBlueprint, self).__init__(name, import_name, **kwargs)
@@ -72,6 +73,9 @@ class APIBlueprint(APIScaffold, Blueprint):
         # Set the operation ID callback function
         self.operation_id_callback: Callable = operation_id_callback
 
+        # Verify the response body
+        self.validate_response = validate_response
+
     def register_api(self, api: "APIBlueprint") -> None:
         """Register a nested APIBlueprint"""
 
@@ -98,32 +102,32 @@ class APIBlueprint(APIScaffold, Blueprint):
         self.register_blueprint(api)
 
     def _add_url_rule(
-            self,
-            rule,
-            endpoint=None,
-            view_func=None,
-            provide_automatic_options=None,
-            **options,
+        self,
+        rule,
+        endpoint=None,
+        view_func=None,
+        provide_automatic_options=None,
+        **options,
     ) -> None:
         self.add_url_rule(rule, endpoint, view_func, provide_automatic_options, **options)
 
     def _collect_openapi_info(
-            self,
-            rule: str,
-            func: Callable,
-            *,
-            tags: Optional[list[Tag]] = None,
-            summary: Optional[str] = None,
-            description: Optional[str] = None,
-            external_docs: Optional[ExternalDocumentation] = None,
-            operation_id: Optional[str] = None,
-            responses: Optional[ResponseDict] = None,
-            deprecated: Optional[bool] = None,
-            security: Optional[list[dict[str, list[Any]]]] = None,
-            servers: Optional[list[Server]] = None,
-            openapi_extensions: Optional[dict[str, Any]] = None,
-            doc_ui: bool = True,
-            method: str = HTTPMethod.GET
+        self,
+        rule: str,
+        func: Callable,
+        *,
+        tags: list[Tag] | None = None,
+        summary: str | None = None,
+        description: str | None = None,
+        external_docs: ExternalDocumentation | None = None,
+        operation_id: str | None = None,
+        responses: ResponseDict | None = None,
+        deprecated: bool | None = None,
+        security: list[dict[str, list[Any]]] | None = None,
+        servers: list[Server] | None = None,
+        openapi_extensions: dict[str, Any] | None = None,
+        doc_ui: bool = True,
+        method: str = HTTPMethod.GET,
     ) -> ParametersTuple:
         """
         Collects OpenAPI specification information for Flask routes and view functions.
@@ -152,10 +156,7 @@ class APIBlueprint(APIScaffold, Blueprint):
 
             # Create operation
             operation = get_operation(
-                func,
-                summary=summary,
-                description=description,
-                openapi_extensions=openapi_extensions
+                func, summary=summary, description=description, openapi_extensions=openapi_extensions
             )
 
             # Set external docs
