@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:37
-from typing import Optional
 
 from pydantic import BaseModel
 
@@ -11,10 +10,8 @@ class Contact(BaseModel):
     https://spec.openapis.org/oas/v3.1.0#contact-object
     """
 
-    name: Optional[str] = None
-    url: Optional[str] = None
-    email: Optional[str] = None
+    name: str | None = None
+    url: str | None = None
+    email: str | None = None
 
-    model_config = {
-        "extra": "allow"
-    }
+    model_config = {"extra": "allow"}
