@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:41
-from typing import TYPE_CHECKING, Optional, Union
+from typing import TYPE_CHECKING, Union
 
 from pydantic import BaseModel
 
@@ -18,12 +18,10 @@ class Encoding(BaseModel):
     https://spec.openapis.org/oas/v3.1.0#encoding-object
     """
 
-    contentType: Optional[str] = None
-    headers: Optional[dict[str, Union[Header, Reference]]] = None
-    style: Optional[str] = None
-    explode: Optional[bool] = None
+    contentType: str | None = None
+    headers: dict[str, Union[Header, Reference]] | None = None
+    style: str | None = None
+    explode: bool | None = None
     allowReserved: bool = False
 
-    model_config = {
-        "extra": "allow"
-    }
+    model_config = {"extra": "allow"}
