@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:43
-from typing import Optional
 
 from pydantic import BaseModel
 
@@ -11,9 +10,7 @@ class ExternalDocumentation(BaseModel):
     https://spec.openapis.org/oas/v3.1.0#external-documentation-object
     """
 
-    description: Optional[str] = None
+    description: str | None = None
     url: str
 
-    model_config = {
-        "extra": "allow"
-    }
+    model_config = {"extra": "allow"}
