@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:45
-from typing import Optional
 
 from pydantic import BaseModel
 
@@ -12,9 +11,7 @@ class License(BaseModel):
     """
 
     name: str
-    identifier: Optional[str] = None
-    url: Optional[str] = None
+    identifier: str | None = None
+    url: str | None = None
 
-    model_config = {
-        "extra": "allow"
-    }
+    model_config = {"extra": "allow"}
