@@ -11,7 +11,4 @@ class Reference(BaseModel):
 
     ref: str = Field(..., alias="$ref")
 
-    model_config = {
-        "extra": "allow",
-        "populate_by_name": True
-    }
+    model_config = {"extra": "allow", "populate_by_name": True}
