@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:53
-from typing import Optional
 
 from pydantic import BaseModel
 
@@ -13,10 +12,8 @@ class RequestBody(BaseModel):
     https://spec.openapis.org/oas/v3.1.0#request-body-object
     """
 
-    description: Optional[str] = None
+    description: str | None = None
     content: dict[str, MediaType]
-    required: Optional[bool] = True
+    required: bool | None = True
 
-    model_config = {
-        "extra": "allow"
-    }
+    model_config = {"extra": "allow"}
