@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:58
-from typing import Optional
 
 from pydantic import BaseModel
 
@@ -11,12 +10,10 @@ class XML(BaseModel):
     https://spec.openapis.org/oas/v3.1.0#xml-object
     """
 
-    name: Optional[str] = None
-    namespace: Optional[str] = None
-    prefix: Optional[str] = None
+    name: str | None = None
+    namespace: str | None = None
+    prefix: str | None = None
     attribute: bool = False
     wrapped: bool = False
 
-    model_config = {
-        "extra": "allow"
-    }
+    model_config = {"extra": "allow"}
