@@ -7,30 +7,30 @@ import re
 import sys
 from enum import Enum
 from http import HTTPStatus
-from typing import get_type_hints, Type, Callable, Optional, Any, DefaultDict
+from typing import Any, Callable, DefaultDict, Type, get_type_hints
 
-from flask import make_response, current_app
+from flask import current_app, make_response
 from flask.wrappers import Response as FlaskResponse
 from pydantic import BaseModel, ValidationError
 from pydantic.json_schema import JsonSchemaMode
 
-from .models import Encoding
-from .models import MediaType
-from .models import OPENAPI3_REF_PREFIX
-from .models import OPENAPI3_REF_TEMPLATE
-from .models import Operation
-from .models import Parameter
-from .models import ParameterInType
-from .models import PathItem
-from .models import RawModel
-from .models import RequestBody
-from .models import Response
-from .models import Schema
-from .models import Tag
+from .models import (
+    OPENAPI3_REF_PREFIX,
+    OPENAPI3_REF_TEMPLATE,
+    Encoding,
+    MediaType,
+    Operation,
+    Parameter,
+    ParameterInType,
+    PathItem,
+    RawModel,
+    RequestBody,
+    Response,
+    Schema,
+    Tag,
+)
 from .models.data_type import DataType
-from .types import ParametersTuple
-from .types import ResponseDict
-from .types import ResponseStrKeyDict
+from .types import ParametersTuple, ResponseDict, ResponseStrKeyDict
 
 HTTP_STATUS = {str(status.value): status.phrase for status in HTTPStatus}
 
@@ -51,10 +51,11 @@ else:
 
 
 def get_operation(
-        func: Callable, *,
-        summary: Optional[str] = None,
-        description: Optional[str] = None,
-        openapi_extensions: Optional[dict[str, Any]] = None,
+    func: Callable,
+    *,
+    summary: str | None = None,
+    description: str | None = None,
+    openapi_extensions: dict[str, Any] | None = None,
 ) -> Operation:
     """
     Return an Operation object with the specified summary and description.
@@ -77,9 +78,9 @@ def get_operation(
 
     # Determine the summary and description based on provided arguments or docstring
     if summary is None:
-        doc_description = lines[0] if len(lines) == 0 else "</br>".join(lines[1:])
+        doc_description = lines[0] if len(lines) == 0 else "<br/>".join(lines[1:])
     else:
-        doc_description = "</br>".join(lines)
+        doc_description = "<br/>".join(lines)
 
     summary = summary or doc_summary
     description = description or doc_description
@@ -124,8 +125,7 @@ def get_operation_id_for_path(*, bp_name: str = "", name: str = "", path: str =
 def get_model_schema(model: Type[BaseModel], mode: JsonSchemaMode = "validation") -> dict:
     """Converts a Pydantic model to an OpenAPI schema."""
 
-    assert inspect.isclass(model) and issubclass(model, BaseModel), \
-        f"{model} is invalid `pydantic.BaseModel`"
+    assert inspect.isclass(model) and issubclass(model, BaseModel), f"{model} is invalid `pydantic.BaseModel`"
 
     model_config = model.model_config
     by_alias = bool(model_config.get("by_alias", True))
@@ -145,7 +145,7 @@ def parse_header(header: Type[BaseModel]) -> tuple[list[Parameter], dict]:
             "name": name,
             "in": ParameterInType.HEADER,
             "required": name in schema.get("required", []),
-            "schema": Schema(**value)
+            "schema": Schema(**value),
         }
         # Parse extra values
         if "description" in value.keys():
@@ -178,7 +178,7 @@ def parse_cookie(cookie: Type[BaseModel]) -> tuple[list[Parameter], dict]:
             "name": name,
             "in": ParameterInType.COOKIE,
             "required": name in schema.get("required", []),
-            "schema": Schema(**value)
+            "schema": Schema(**value),
         }
         # Parse extra values
         if "description" in value.keys():
@@ -207,12 +207,7 @@ def parse_path(path: Type[BaseModel]) -> tuple[list[Parameter], dict]:
     properties = schema.get("properties", {})
 
     for name, value in properties.items():
-        data = {
-            "name": name,
-            "in": ParameterInType.PATH,
-            "required": True,
-            "schema": Schema(**value)
-        }
+        data = {"name": name, "in": ParameterInType.PATH, "required": True, "schema": Schema(**value)}
         # Parse extra values
         if "description" in value.keys():
             data["description"] = value.get("description")
@@ -244,7 +239,7 @@ def parse_query(query: Type[BaseModel]) -> tuple[list[Parameter], dict]:
             "name": name,
             "in": ParameterInType.QUERY,
             "required": name in schema.get("required", []),
-            "schema": Schema(**value)
+            "schema": Schema(**value),
         }
         # Parse extra values
         if "description" in value.keys():
@@ -266,7 +261,7 @@ def parse_query(query: Type[BaseModel]) -> tuple[list[Parameter], dict]:
 
 
 def parse_form(
-        form: Type[BaseModel],
+    form: Type[BaseModel],
 ) -> tuple[dict[str, MediaType], dict]:
     """Parses a form model and returns a list of parameters and component schemas."""
     schema = get_model_schema(form)
@@ -299,7 +294,7 @@ def parse_form(
 
 
 def parse_body(
-        body: Type[BaseModel],
+    body: Type[BaseModel],
 ) -> tuple[dict[str, MediaType], dict]:
     """Parses a body model and returns a list of parameters and component schemas."""
     schema = get_model_schema(body)
@@ -308,11 +303,7 @@ def parse_body(
     original_title = schema.get("title") or body.__name__
     title = normalize_name(original_title)
     components_schemas[title] = Schema(**schema)
-    content = {
-        "application/json": MediaType(
-            schema=Schema(**{"$ref": f"{OPENAPI3_REF_PREFIX}/{title}"})
-        )
-    }
+    content = {"application/json": MediaType(schema=Schema(**{"$ref": f"{OPENAPI3_REF_PREFIX}/{title}"}))}
 
     # Parse definitions
     definitions = schema.get("$defs", {})
@@ -322,11 +313,7 @@ def parse_body(
     return content, components_schemas
 
 
-def get_responses(
-        responses: ResponseStrKeyDict,
-        components_schemas: dict,
-        operation: Operation
-) -> None:
+def get_responses(responses: ResponseStrKeyDict, components_schemas: dict, operation: Operation) -> None:
     _responses = {}
     _schemas = {}
 
@@ -344,10 +331,8 @@ def get_responses(
             name = normalize_name(original_title)
             _responses[key] = Response(
                 description=HTTP_STATUS.get(key, ""),
-                content={
-                    "application/json": MediaType(
-                        schema=Schema(**{"$ref": f"{OPENAPI3_REF_PREFIX}/{name}"})
-                    )})
+                content={"application/json": MediaType(schema=Schema(**{"$ref": f"{OPENAPI3_REF_PREFIX}/{name}"}))},
+            )
 
             model_config: DefaultDict[str, Any] = response.model_config  # type: ignore
             openapi_extra = model_config.get("openapi_extra", {})
@@ -381,10 +366,7 @@ def get_responses(
 
 
 def parse_and_store_tags(
-        new_tags: list[Tag],
-        old_tags: list[Tag],
-        old_tag_names: list[str],
-        operation: Operation
+    new_tags: list[Tag], old_tags: list[Tag], old_tag_names: list[str], operation: Operation
 ) -> None:
     """
     Parses new tags, stores them in an old_tags list if they are not already present,
@@ -411,11 +393,11 @@ def parse_and_store_tags(
 
 
 def parse_parameters(
-        func: Callable,
-        *,
-        components_schemas: Optional[dict] = None,
-        operation: Optional[Operation] = None,
-        doc_ui: bool = True,
+    func: Callable,
+    *,
+    components_schemas: dict | None = None,
+    operation: Operation | None = None,
+    doc_ui: bool = True,
 ) -> ParametersTuple:
     """
     Parses the parameters of a given function and returns the types for header, cookie, path,
@@ -445,13 +427,13 @@ def parse_parameters(
     annotations = get_type_hints(func)
 
     # Get the types for header, cookie, path, query, form, and body parameters
-    header: Optional[Type[BaseModel]] = annotations.get("header")
-    cookie: Optional[Type[BaseModel]] = annotations.get("cookie")
-    path: Optional[Type[BaseModel]] = annotations.get("path")
-    query: Optional[Type[BaseModel]] = annotations.get("query")
-    form: Optional[Type[BaseModel]] = annotations.get("form")
-    body: Optional[Type[BaseModel]] = annotations.get("body")
-    raw: Optional[Type[RawModel]] = annotations.get("raw")
+    header: Type[BaseModel] | None = annotations.get("header")
+    cookie: Type[BaseModel] | None = annotations.get("cookie")
+    path: Type[BaseModel] | None = annotations.get("path")
+    query: Type[BaseModel] | None = annotations.get("query")
+    form: Type[BaseModel] | None = annotations.get("form")
+    body: Type[BaseModel] | None = annotations.get("body")
+    raw: Type[RawModel] | None = annotations.get("raw")
 
     # If doc_ui is False, return the types without further processing
     if doc_ui is False:
@@ -520,13 +502,9 @@ def parse_parameters(
         _content = {}
         for mimetype in raw.mimetypes:
             if mimetype.startswith("application/json"):
-                _content[mimetype] = MediaType(
-                    schema=Schema(type=DataType.OBJECT)
-                )
+                _content[mimetype] = MediaType(schema=Schema(type=DataType.OBJECT))
             else:
-                _content[mimetype] = MediaType(
-                    schema=Schema(type=DataType.STRING)
-                )
+                _content[mimetype] = MediaType(schema=Schema(type=DataType.STRING))
         request_body = RequestBody(content=_content)
         operation.requestBody = request_body
 
@@ -594,6 +572,42 @@ def make_validation_error_response(e: ValidationError) -> FlaskResponse:
     return response
 
 
+def run_validate_response(response: Any, responses: ResponseDict | None = None) -> Any:
+    """Validate response"""
+    if responses is None:
+        return response
+
+    if isinstance(response, tuple):  # noqa
+        _resp, status_code = response[:2]
+    elif isinstance(response, FlaskResponse):
+        if response.mimetype != "application/json":
+            # only application/json
+            return response
+        _resp, status_code = response.json, response.status_code  # noqa
+    else:
+        _resp, status_code = response, 200
+
+    # status_code is http.HTTPStatus
+    if isinstance(status_code, HTTPStatus):
+        status_code = status_code.value
+
+    resp_model = responses.get(status_code)
+
+    if resp_model is None:
+        return response
+
+    assert inspect.isclass(resp_model) and issubclass(resp_model, BaseModel), (
+        f"{resp_model} is invalid `pydantic.BaseModel`"
+    )
+
+    if isinstance(_resp, str):
+        resp_model.model_validate_json(_resp)
+    else:
+        resp_model.model_validate(_resp)
+
+    return response
+
+
 def parse_rule(rule: str, url_prefix=None) -> str:
     trail_slash = rule.endswith("/")
 
