@@ -16,7 +16,7 @@ class MyModel(BaseModel):
     num_2: int = Field(..., gt=1, lt=10)
 
 
-@app.post('/book')
+@app.post("/book")
 def create_book(body: MyModel):
     print(body)  # pragma: no cover
 
@@ -32,11 +32,11 @@ def test_openapi(client):
     assert resp.status_code == 200
     assert resp.json == app.api_doc
 
-    model_props = resp.json['components']['schemas']['MyModel']['properties']
-    num_1_props = model_props['num_1']
-    num_2_props = model_props['num_2']
+    model_props = resp.json["components"]["schemas"]["MyModel"]["properties"]
+    num_1_props = model_props["num_1"]
+    num_2_props = model_props["num_2"]
 
-    assert num_1_props['minimum'] == 1
-    assert num_1_props['maximum'] == 10
-    assert num_2_props['exclusiveMinimum'] == 1
-    assert num_2_props['exclusiveMaximum'] == 10
+    assert num_1_props["minimum"] == 1
+    assert num_1_props["maximum"] == 10
+    assert num_2_props["exclusiveMinimum"] == 1
+    assert num_2_props["exclusiveMaximum"] == 10
