@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Generic, TypeVar, Optional, Literal
+from typing import Generic, Literal, TypeVar
 
 from pydantic import BaseModel, Field
 
@@ -15,27 +15,15 @@ def test_responses_are_replicated_in_open_api(request):
 
     class BaseResponse(BaseModel):
         """Base description"""
+
         test: int
 
         model_config = dict(
             openapi_extra={
                 "description": "Custom description",
-                "headers": {
-                    "location": {
-                        "description": "URL of the new resource",
-                        "schema": {"type": "string"}
-                    }
-                },
-                "content": {
-                    "text/plain": {
-                        "schema": {"type": "string"}
-                    }
-                },
-                "links": {
-                    "dummy": {
-                        "description": "dummy link"
-                    }
-                }
+                "headers": {"location": {"description": "URL of the new resource", "schema": {"type": "string"}}},
+                "content": {"text/plain": {"schema": {"type": "string"}}},
+                "links": {"dummy": {"description": "dummy link"}},
             }
         )
 
@@ -48,27 +36,14 @@ def test_responses_are_replicated_in_open_api(request):
         assert resp.status_code == 200
         assert resp.json["paths"]["/test"]["get"]["responses"]["201"] == {
             "description": "Custom description",
-            "headers": {
-                "location": {
-                    "description": "URL of the new resource",
-                    "schema": {"type": "string"}
-                }
-            },
+            "headers": {"location": {"description": "URL of the new resource", "schema": {"type": "string"}}},
             "content": {
                 # This content is coming from responses
-                "application/json": {
-                    "schema": {"$ref": "#/components/schemas/BaseResponse"}
-                },
+                "application/json": {"schema": {"$ref": "#/components/schemas/BaseResponse"}},
                 # While this one comes from responses
-                "text/plain": {
-                    "schema": {"type": "string"}
-                }
+                "text/plain": {"schema": {"type": "string"}},
             },
-            "links": {
-                "dummy": {
-                    "description": "dummy link"
-                }
-            }
+            "links": {"dummy": {"description": "dummy link"}},
         }
 
 
@@ -81,24 +56,11 @@ def test_none_responses_are_replicated_in_open_api(request):
         responses={
             "204": {
                 "description": "Custom description",
-                "headers": {
-                    "x-my-special-header": {
-                        "description": "Custom header",
-                        "schema": {"type": "string"}
-                    }
-                },
-                "content": {
-                    "text/plain": {
-                        "schema": {"type": "string"}
-                    }
-                },
-                "links": {
-                    "dummy": {
-                        "description": "dummy link"
-                    }
-                }
+                "headers": {"x-my-special-header": {"description": "Custom header", "schema": {"type": "string"}}},
+                "content": {"text/plain": {"schema": {"type": "string"}}},
+                "links": {"dummy": {"description": "dummy link"}},
             }
-        }
+        },
     )
     def endpoint_test():
         return b"", 204  # pragma: no cover
@@ -108,22 +70,9 @@ def test_none_responses_are_replicated_in_open_api(request):
         assert resp.status_code == 200
         assert resp.json["paths"]["/test"]["get"]["responses"]["204"] == {
             "description": "Custom description",
-            "headers": {
-                "x-my-special-header": {
-                    "description": "Custom header",
-                    "schema": {"type": "string"}
-                }
-            },
-            "content": {
-                "text/plain": {
-                    "schema": {"type": "string"}
-                }
-            },
-            "links": {
-                "dummy": {
-                    "description": "dummy link"
-                }
-            }
+            "headers": {"x-my-special-header": {"description": "Custom header", "schema": {"type": "string"}}},
+            "content": {"text/plain": {"schema": {"type": "string"}}},
+            "links": {"dummy": {"description": "dummy link"}},
         }
 
 
@@ -136,24 +85,11 @@ def test_responses_are_replicated_in_open_api2(request):
         responses={
             "201": {
                 "description": "Custom description",
-                "headers": {
-                    "location": {
-                        "description": "URL of the new resource",
-                        "schema": {"type": "string"}
-                    }
-                },
-                "content": {
-                    "text/plain": {
-                        "schema": {"type": "string"}
-                    }
-                },
-                "links": {
-                    "dummy": {
-                        "description": "dummy link"
-                    }
-                }
+                "headers": {"location": {"description": "URL of the new resource", "schema": {"type": "string"}}},
+                "content": {"text/plain": {"schema": {"type": "string"}}},
+                "links": {"dummy": {"description": "dummy link"}},
             }
-        }
+        },
     )
     def endpoint_test():
         return b"", 201  # pragma: no cover
@@ -163,22 +99,9 @@ def test_responses_are_replicated_in_open_api2(request):
         assert resp.status_code == 200
         assert resp.json["paths"]["/test"]["get"]["responses"]["201"] == {
             "description": "Custom description",
-            "headers": {
-                "location": {
-                    "description": "URL of the new resource",
-                    "schema": {"type": "string"}
-                }
-            },
-            "content": {
-                "text/plain": {
-                    "schema": {"type": "string"}
-                }
-            },
-            "links": {
-                "dummy": {
-                    "description": "dummy link"
-                }
-            }
+            "headers": {"location": {"description": "URL of the new resource", "schema": {"type": "string"}}},
+            "content": {"text/plain": {"schema": {"type": "string"}}},
+            "links": {"dummy": {"description": "dummy link"}},
         }
 
 
@@ -191,19 +114,10 @@ def test_responses_without_content_are_replicated_in_open_api(request):
         responses={
             "201": {
                 "description": "Custom description",
-                "headers": {
-                    "location": {
-                        "description": "URL of the new resource",
-                        "schema": {"type": "string"}
-                    }
-                },
-                "links": {
-                    "dummy": {
-                        "description": "dummy link"
-                    }
-                }
+                "headers": {"location": {"description": "URL of the new resource", "schema": {"type": "string"}}},
+                "links": {"dummy": {"description": "dummy link"}},
             }
-        }
+        },
     )
     def endpoint_test():
         return b"", 201  # pragma: no cover
@@ -213,22 +127,14 @@ def test_responses_without_content_are_replicated_in_open_api(request):
         assert resp.status_code == 200
         assert resp.json["paths"]["/test"]["get"]["responses"]["201"] == {
             "description": "Custom description",
-            "headers": {
-                "location": {
-                    "description": "URL of the new resource",
-                    "schema": {"type": "string"}
-                }
-            },
-            "links": {
-                "dummy": {
-                    "description": "dummy link"
-                }
-            }
+            "headers": {"location": {"description": "URL of the new resource", "schema": {"type": "string"}}},
+            "links": {"dummy": {"description": "dummy link"}},
         }
 
 
 class BaseRequest(BaseModel):
     """Base description"""
+
     test_int: int
     test_str: str
 
@@ -244,14 +150,10 @@ class BaseRequestGeneric(BaseModel, Generic[T]):
                     "value": {
                         "test_int": -1,
                         "test_str": "negative",
-                    }
+                    },
                 },
-                "Example 02": {
-                    "externalValue": "https://example.org/examples/second-example.xml"
-                },
-                "Example 03": {
-                    "$ref": "#/components/examples/third-example"
-                }
+                "Example 02": {"externalValue": "https://example.org/examples/second-example.xml"},
+                "Example 03": {"$ref": "#/components/examples/third-example"},
             }
         }
     )
@@ -275,12 +177,12 @@ def test_body_examples_are_replicated_in_open_api(request):
                     "examples": {
                         "Example 01": {"summary": "An example", "value": {"test_int": -1, "test_str": "negative"}},
                         "Example 02": {"externalValue": "https://example.org/examples/second-example.xml"},
-                        "Example 03": {"$ref": "#/components/examples/third-example"}
+                        "Example 03": {"$ref": "#/components/examples/third-example"},
                     },
-                    "schema": {"$ref": "#/components/schemas/BaseRequestGeneric_BaseRequest_"}
+                    "schema": {"$ref": "#/components/schemas/BaseRequestGeneric_BaseRequest_"},
                 }
             },
-            "required": True
+            "required": True,
         }
         assert resp.json["components"]["schemas"]["BaseRequestGeneric_BaseRequest_"] == {
             "properties": {"detail": {"$ref": "#/components/schemas/BaseRequest"}},
@@ -302,7 +204,7 @@ def test_form_examples(request):
                     "value": {
                         "test_int": -1,
                         "test_str": "negative",
-                    }
+                    },
                 }
             }
         }
@@ -322,10 +224,10 @@ def test_form_examples(request):
                     "schema": {"$ref": "#/components/schemas/BaseRequestGeneric_BaseRequest_"},
                     "examples": {
                         "Example 01": {"summary": "An example", "value": {"test_int": -1, "test_str": "negative"}}
-                    }
+                    },
                 }
             },
-            "required": True
+            "required": True,
         }
         assert resp.json["components"]["schemas"]["BaseRequestGeneric_BaseRequest_"] == {
             "properties": {"detail": {"$ref": "#/components/schemas/BaseRequest"}},
@@ -351,7 +253,8 @@ def test_body_with_complex_object(request):
         resp = client.get("/openapi/openapi.json")
         assert resp.status_code == 200
         assert {"properties", "required", "title", "type"} == set(
-            resp.json["components"]["schemas"]["BaseRequestBody"].keys())
+            resp.json["components"]["schemas"]["BaseRequestBody"].keys()
+        )
 
 
 class Detail(BaseModel):
@@ -380,9 +283,7 @@ def test_responses_with_generics(request):
         assert resp.json["paths"]["/test"]["get"]["responses"]["201"] == {
             "description": "Created",
             "content": {
-                "application/json": {
-                    "schema": {"$ref": "#/components/schemas/ListGenericResponse_Detail_"}
-                },
+                "application/json": {"schema": {"$ref": "#/components/schemas/ListGenericResponse_Detail_"}},
             },
         }
 
@@ -394,8 +295,9 @@ def test_responses_with_generics(request):
 
 
 class PathParam(BaseModel):
-    type_name: str = Field(..., description="id for path", max_length=300,
-                           json_schema_extra={"deprecated": False, "example": "42"})
+    type_name: str = Field(
+        ..., description="id for path", max_length=300, json_schema_extra={"deprecated": False, "example": "42"}
+    )
 
 
 def test_path_parameter_object(request):
@@ -428,8 +330,9 @@ def test_path_parameter_object(request):
 
 
 class QueryParam(BaseModel):
-    count: int = Field(..., description="count of param", le=1000.0,
-                       json_schema_extra={"deprecated": True, "example": 100})
+    count: int = Field(
+        ..., description="count of param", le=1000.0, json_schema_extra={"deprecated": True, "example": 100}
+    )
 
 
 def test_query_parameter_object(request):
@@ -485,7 +388,7 @@ def test_header_parameter_object(request):
             "in": "header",
             "name": "app_name",
             "required": False,
-            "schema": {"description": "app name", "title": "App Name", "type": "string", "default": None}
+            "schema": {"description": "app name", "title": "App Name", "type": "string", "default": None},
         }
         assert resp.json["paths"]["/test"]["post"]["parameters"][1] == {
             "description": "app name",
@@ -493,14 +396,19 @@ def test_header_parameter_object(request):
             "example": "aaa",
             "name": "app_name",
             "required": False,
-            "schema": {"description": "app name", "example": "aaa", "title": "App Name", "type": "string",
-                       "default": None}
+            "schema": {
+                "description": "app name",
+                "example": "aaa",
+                "title": "App Name",
+                "type": "string",
+                "default": None,
+            },
         }
 
 
 class Model(BaseModel):
-    one: Optional[int] = Field(default=None)
-    two: Optional[int] = Field(default=2)
+    one: int | None = Field(default=None)
+    two: int | None = Field(default=2)
 
 
 def test_default_none(request):
@@ -558,22 +466,47 @@ def test_prefix_items(request):
         print([])  # pragma: no cover
 
     schema = test_app.api_doc["paths"]["/test"]["post"]["requestBody"]["content"]["application/json"]["schema"]
-    assert schema == {'$ref': '#/components/schemas/TupleModel'}
+    assert schema == {"$ref": "#/components/schemas/TupleModel"}
     components = test_app.api_doc["components"]["schemas"]
-    assert components["TupleModel"] == {'properties': {'my_tuple': {'maxItems': 2,
-                             'minItems': 2,
-                             'prefixItems': [{'enum': ['a', 'b'],
-                                              'type': 'string'},
-                                             {'enum': ['c', 'd'],
-                                              'type': 'string'}],
-                             'title': 'My Tuple',
-                             'type': 'array'}},
- 'required': ['my_tuple'],
- 'title': 'TupleModel',
- 'type': 'object'}
+    assert components["TupleModel"] == {
+        "properties": {
+            "my_tuple": {
+                "maxItems": 2,
+                "minItems": 2,
+                "prefixItems": [{"enum": ["a", "b"], "type": "string"}, {"enum": ["c", "d"], "type": "string"}],
+                "title": "My Tuple",
+                "type": "array",
+            }
+        },
+        "required": ["my_tuple"],
+        "title": "TupleModel",
+        "type": "object",
+    }
 
 
 def test_schema_bigint(request):
     max_nr = 9223372036854775807
     obj = Schema(maximum=max_nr)
     assert obj.model_dump()["maximum"] == max_nr
+
+
+def test_convert_literal_with_single_value_to_const(request):
+    test_app = OpenAPI(request.node.name)
+    test_app.config["TESTING"] = True
+
+    class MyResponse(BaseModel):
+        foobar: Literal["baz"]
+
+    @test_app.post("/test", responses={200: MyResponse})
+    def endpoint_test():
+        print("do nothing")
+
+    with test_app.test_client() as client:
+        resp = client.get("/openapi/openapi.json")
+        assert resp.status_code == 200
+        print("###", resp.json)
+        assert resp.json["components"]["schemas"]["MyResponse"]["properties"]["foobar"] == {
+            "const": "baz",
+            "title": "Foobar",
+            "type": "string",
+        }
