@@ -5,23 +5,16 @@ from __future__ import annotations
 
 import json
 from http import HTTPStatus
-from typing import Optional
 
 import pytest
 from flask import Response
-from pydantic import BaseModel, RootModel, Field
+from pydantic import BaseModel, Field, RootModel
 
-from flask_openapi3 import ExternalDocumentation
-from flask_openapi3 import Info, Tag
-from flask_openapi3 import OpenAPI
+from flask_openapi3 import ExternalDocumentation, Info, OpenAPI, Tag
 
-info = Info(title='book API', version='1.0.0')
+info = Info(title="book API", version="1.0.0")
 
-jwt = {
-    "type": "http",
-    "scheme": "bearer",
-    "bearerFormat": "JWT"
-}
+jwt = {"type": "http", "scheme": "bearer", "bearerFormat": "JWT"}
 security_schemes = {"jwt": jwt}
 
 
@@ -45,26 +38,26 @@ app = OpenAPI(
 app.config["TESTING"] = True
 
 security = [{"jwt": []}]
-book_tag = Tag(name='book', description='Book')
+book_tag = Tag(name="book", description="Book")
 
 
 class BookQuery(BaseModel):
-    age: Optional[int] = Field(None, description='Age')
+    age: int | None = Field(None, description="Age")
 
 
 class BookBody(BaseModel):
-    age: Optional[int] = Field(..., ge=2, le=4, description='Age')
-    author: str = Field(None, min_length=2, max_length=4, description='Author')
+    age: int | None = Field(..., ge=2, le=4, description="Age")
+    author: str = Field(None, min_length=2, max_length=4, description="Author")
 
 
 class BookPath(BaseModel):
-    bid: int = Field(..., description='book id')
+    bid: int = Field(..., description="book id")
 
 
 class BookBodyWithID(BaseModel):
-    bid: int = Field(..., description='book id')
-    age: Optional[int] = Field(None, ge=2, le=4, description='Age')
-    author: str = Field(None, min_length=2, max_length=4, description='Author')
+    bid: int = Field(..., description="book id")
+    age: int | None = Field(None, ge=2, le=4, description="Age")
+    author: str = Field(None, min_length=2, max_length=4, description="Author")
 
 
 class BaseResponse(BaseModel):
@@ -98,14 +91,14 @@ def client():
 
 
 @app.get(
-    '/book/<int:bid>',
+    "/book/<int:bid>",
     tags=[book_tag],
     operation_id="get_book_id",
     external_docs=ExternalDocumentation(
-        url="https://www.openapis.org/",
-        description="Something great got better, get excited!"),
+        url="https://www.openapis.org/", description="Something great got better, get excited!"
+    ),
     responses={"200": BookResponse},
-    security=security
+    security=security,
 )
 def get_book(path: BookPath):
     """Get a book
@@ -116,85 +109,74 @@ def get_book(path: BookPath):
         return NotFoundResponse().model_dump(), 404
 
 
-@app.get('/book', tags=[book_tag], responses={"200": BookListResponseV1})
+@app.get("/book", tags=[book_tag], responses={"200": BookListResponseV1})
 def get_books(query: BookBody):
     """get books
     to get all books
     """
     assert query.age == 3
-    assert query.author == 'joy'
+    assert query.author == "joy"
     return {
         "code": 0,
         "message": "ok",
-        "data": [
-            {"bid": 1, "age": query.age, "author": "b1"},
-            {"bid": 2, "age": query.age, "author": "b2"}
-        ]
+        "data": [{"bid": 1, "age": query.age, "author": "b1"}, {"bid": 2, "age": query.age, "author": "b2"}],
     }
 
 
-@app.get('/book_v2', tags=[book_tag], responses={"200": BookListResponseV2})
+@app.get("/book_v2", tags=[book_tag], responses={"200": BookListResponseV2})
 def get_books_v2(query: BookBody):
     """get books
     to get all books (v2)
     """
     assert query.age == 3
-    assert query.author == 'joy'
-    return {
-        "books": [
-            {"bid": 1, "age": query.age, "author": "b1"},
-            {"bid": 2, "age": query.age, "author": "b2"}
-        ]
-    }
+    assert query.author == "joy"
+    return {"books": [{"bid": 1, "age": query.age, "author": "b1"}, {"bid": 2, "age": query.age, "author": "b2"}]}
 
 
-@app.get('/book_v3', tags=[book_tag], responses={"200": BookListResponseV3})
+@app.get("/book_v3", tags=[book_tag], responses={"200": BookListResponseV3})
 def get_books_v3(query: BookBody):
     """get books
     to get all books (v3)
     """
     assert query.age == 3
-    assert query.author == 'joy'
+    assert query.author == "joy"
 
-    books = [
-        {"bid": 1, "age": query.age, "author": "b1"},
-        {"bid": 2, "age": query.age, "author": "b2"}
-    ]
+    books = [{"bid": 1, "age": query.age, "author": "b1"}, {"bid": 2, "age": query.age, "author": "b2"}]
     # A `list` have to be converted to json-format `str` returned as a `Response` object,
     # because flask doesn't support returning a `list` as a response
-    return Response(json.dumps(books), status=200, headers={'Content-Type': 'application/json'})
+    return Response(json.dumps(books), status=200, headers={"Content-Type": "application/json"})
 
 
-@app.post('/book', tags=[book_tag], responses={"200": BaseResponse})
+@app.post("/book", tags=[book_tag], responses={"200": BaseResponse})
 def create_book(body: BookBody):
     assert body.age == 3
     return {"code": 0, "message": "ok"}, HTTPStatus.OK
 
 
-@app.put('/book/<int:bid>', tags=[book_tag])
+@app.put("/book/<int:bid>", tags=[book_tag])
 def update_book(path: BookPath, body: BookBody):
     assert path.bid == 1
     assert body.age == 3
     return {"code": 0, "message": "ok"}
 
 
-@app.patch('/book/<int:bid>', tags=[book_tag], doc_ui=False)
+@app.patch("/book/<int:bid>", tags=[book_tag], doc_ui=False)
 def update_book1(path: BookPath, body: BookBody):
     assert path.bid == 1
     assert body.age == 3
     return {"code": 0, "message": "ok"}
 
 
-@app.delete('/book/<int:bid>', tags=[book_tag], responses={"200": BaseResponse})
+@app.delete("/book/<int:bid>", tags=[book_tag], responses={"200": BaseResponse})
 def delete_book(path: BookPath):
     assert path.bid == 1
     return {"code": 0, "message": "ok"}
 
 
-@app.delete('/book_no_response/<int:bid>', tags=[book_tag], responses={"204": None})
+@app.delete("/book_no_response/<int:bid>", tags=[book_tag], responses={"204": None})
 def delete_book_no_response(path: BookPath):
     assert path.bid == 1
-    return b'', 204
+    return b"", 204
 
 
 def test_openapi(client):
